#include <QDebug>
#include "clock.h"
#include <QtCore>
#include <QtScript>
#include "TextInputDialog.h"

QScriptValue toUnicode(QScriptContext *context, QScriptEngine *engine) 
{
	QString s = context->argument(0).toString();
	return QScriptValue(engine, QString::fromUtf8(s.toAscii().data()));
}

QScriptValue newTextInputDialog(QScriptContext *context, QScriptEngine *engine) 
{
	return engine->newQObject(new TextInputDialog(), QScriptEngine::ScriptOwnership);
}


Clock::Clock(QWidget *parent) : QDialog(parent)
{
	setupUi(this);
	m_timeFormat = "hh:mm:ss";
	m_dateFormat = "yyyy-MM-dd (dddd)";
	QFile scriptFile("clock.config");
	timer = new QTimer(this);
	timer->setObjectName("timer");
	timer->setInterval(1000);
	connect(timer, SIGNAL(timeout()), this, SLOT(onTimeout()));

	QString script;
	if (scriptFile.exists())
	{
		scriptFile.open(QIODevice::ReadOnly);
		script.append(scriptFile.readAll());
		scriptFile.close();
	}
	engine = new QScriptEngine();

	QScriptValue objectWnd = engine->newQObject(this);
	engine->globalObject().setProperty("MainWindow", objectWnd);
	QScriptValue func = engine->newFunction(toUnicode);
	engine->globalObject().setProperty("toUnicode", func);
	QScriptValue func2 = engine->newFunction(newTextInputDialog);
	engine->globalObject().setProperty("newTextInputDialog", func2);
	
	QScriptValue result = engine->evaluate(script);
	if (result.isError())
		qDebug() << "Script error:" << result.toString();
	
	timer->start();
}

Clock::~Clock()
{
	timer->stop();
	delete timer;
	delete engine;
}

void Clock::onTimeout()
{
	timeLabel->setText(QTime::currentTime().toString(m_timeFormat));
	dateLabel->setText(QDate::currentDate().toString(m_dateFormat));
}

void Clock::execute(const QString & command)
{
	QProcess::execute(command);
}
