CREATE TABLE artists(
artist_id serial,
name char varying(255) NOT NULL UNIQUE,
PRIMARY KEY(artist_id)
);

CREATE TABLE albums(
album_id serial,
artist_id int4 NOT NULL,
title char varying(255) NOT NULL,
release_year char(4),
PRIMARY KEY(album_id),
FOREIGN KEY(artist_id) REFERENCES artists
);

CREATE TABLE compositions(
composition_id serial,
artist_id int4 NOT NULL,
album_id int4,
release_year char(4),
title char varying(255) NOT NULL,
PRIMARY KEY(composition_id),
FOREIGN KEY(artist_id) REFERENCES artists,
FOREIGN KEY(album_id) REFERENCES albums
);

CREATE VIEW view_all (artist, title, album, composition_release_year, album_release_year) AS SELECT artists.name, compositions.title, albums.title, compositions.release_year, albums.release_year FROM compositions LEFT OUTER JOIN albums ON (compositions.album_id = albums.album_id) RIGHT OUTER JOIN artists ON (compositions.artist_id = artists.artist_id);

INSERT INTO artists (name) VALUES ('Ludwig van Beethoven');
INSERT INTO artists (name) VALUES ('Nightwish');
INSERT INTO artists (name) VALUES ('Richard Wagner');
INSERT INTO artists (name) VALUES ('Beto Vazquez Infinity');

INSERT INTO albums (artist_id, title, release_year) VALUES ((select artist_id from artists where name = 'Ludwig van Beethoven'), 'Symphonie No 9, opus 125', '1824');
INSERT INTO albums (artist_id, title, release_year) VALUES ((select artist_id from artists where name = 'Nightwish'), 'Highest Hopes', '2005');
INSERT INTO albums (artist_id, title, release_year) VALUES ((select artist_id from artists where name = 'Nightwish'), 'Oceanborn', '1998');
INSERT INTO albums (artist_id, title, release_year) VALUES ((select artist_id from artists where name = 'Richard Wagner'), 'Twilight of the Gods', '1876');
INSERT INTO albums (artist_id, title, release_year) VALUES ((select artist_id from artists where name = 'Beto Vazquez Infinity'), 'Beto Vazquez Infinity', '2001');

INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Nightwish'), (select album_id from albums where title = 'Oceanborn'), 'Walking In the Air', '1998');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Nightwish'), (select album_id from albums where title = ''), 'Outro', '2001');

INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Nightwish'), (select album_id from albums where title = 'Oceanborn'), 'Swanheart', '1998');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Nightwish'), (select album_id from albums where title = 'Highest Hopes'), 'Nemo', '1998');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Ludwig van Beethoven'), (select album_id from albums where title = 'Symphonie No 9, opus 125'), 'Part 1 - Allegro ma non Tropo', '1824');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Ludwig van Beethoven'), (select album_id from albums where title = 'Symphonie No 9, opus 125'), 'Part 2 - Molto Vivace', '1824');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Ludwig van Beethoven'), (select album_id from albums where title = 'Symphonie No 9, opus 125'), 'Part 3 - Adagio Molto e Cantabile', '1824');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Ludwig van Beethoven'), (select album_id from albums where title = 'Symphonie No 9, opus 125'), 'Part 4 - Presto- Allegro assai', '1824');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Richard Wagner'), (select album_id from albums where title = 'Twilight of the Gods'), 'Prologue', '1876');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Richard Wagner'), (select album_id from albums where title = 'Twilight of the Gods'), 'Act I', '1876');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Richard Wagner'), (select album_id from albums where title = 'Twilight of the Gods'), 'Act II', '1876');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Richard Wagner'), (select album_id from albums where title = 'Twilight of the Gods'), 'Act III', '1876');
INSERT INTO compositions (artist_id, album_id, title, release_year) VALUES ((select artist_id from artists where name = 'Beto Vazquez Infinity'), (select album_id from albums where title = 'Beto Vazquez Infinity'), 'Wizard', '2001');



